@@ -19,6 +19,7 @@ nonexistent = os.path.join(testdir, "must-not-exist")
 # A file that is guaranteed to exist
 testfile = os.path.abspath(__file__)
 
+
 class TestContext(TestCase):
     @classmethod
     def setUpClass(cls):
@@ -32,7 +33,7 @@ class TestContext(TestCase):
         cls._sample_keymap_file.close()
 
     def test_create(self):
-        ctx = xkb.Context()
+        xkb.Context()
 
     def test_default_includes(self):
         ctx = xkb.Context(no_default_includes=True)
@@ -59,7 +60,8 @@ class TestContext(TestCase):
         ctx = xkb.Context()
         default_num_include_paths = ctx.num_include_paths()
         ctx.include_path_append(testdir)
-        self.assertEqual(ctx.num_include_paths(), default_num_include_paths + 1)
+        self.assertEqual(ctx.num_include_paths(),
+                         default_num_include_paths + 1)
 
     def test_set_log_level(self):
         ctx = xkb.Context()
@@ -75,13 +77,15 @@ class TestContext(TestCase):
 
     def test_set_log_handler(self):
         messages = []
+
         def handler(context, level, message):
             messages.append(message)
+
         ctx = xkb.Context()
         ctx.set_log_level(xkb.lib.XKB_LOG_LEVEL_DEBUG)
         ctx.set_log_verbosity(10)
         ctx.set_log_fn(handler)
-        km = ctx.keymap_new_from_string(sample_keymap_string)
+        ctx.keymap_new_from_string(sample_keymap_string)
         self.assertNotEqual(len(messages), 0)
 
     def test_keymap_new_from_names_with_args(self):
@@ -129,6 +133,7 @@ class TestContext(TestCase):
         km = ctx.keymap_new_from_buffer(test_data, length=length)
         self.assertIsNotNone(km)
 
+
 # This class makes use of the details of the sample keymap in
 # sample_keymap_string.
 class TestKeymap(TestCase):
@@ -224,29 +229,38 @@ class TestKeymap(TestCase):
     def test_keymap_state_new(self):
         self.assertIsNotNone(self.km.state_new())
 
+
 class TestBitEnum(TestCase):
     def test_StateComponent(self):
         a = xkb.XKB_STATE_MODS_DEPRESSED
         b = xkb.XKB_STATE_MODS_LATCHED
         self.assertIsInstance(a | b, xkb.StateComponent)
-        self.assertEqual(str(a | b),
-                         "StateComponent.XKB_STATE_MODS_LATCHED|XKB_STATE_MODS_DEPRESSED")
-        c = a | b | 0x1000000
-        self.assertEqual(str(c),
-                         "StateComponent.16777216|XKB_STATE_MODS_LATCHED|XKB_STATE_MODS_DEPRESSED")
+
+        # The order in which enum members are listed is implementation
+        # defined and does in practice vary between different Python
+        # versions. Both possibilities should be acceptable.
+
+        self.assertIn(
+            str(a | b),
+            ("StateComponent.XKB_STATE_MODS_LATCHED|XKB_STATE_MODS_DEPRESSED",
+             "StateComponent.XKB_STATE_MODS_DEPRESSED|XKB_STATE_MODS_LATCHED"))
+        c = a | 0x1000000
+        self.assertIn(
+            str(c),
+            ("StateComponent.16777216|XKB_STATE_MODS_DEPRESSED",
+             "StateComponent.XKB_STATE_MODS_DEPRESSED|16777216"))
 
     def test_StateMatch(self):
-        self.assertEqual(
-            str(xkb.XKB_STATE_MATCH_ANY|xkb.XKB_STATE_MATCH_ALL
-                |xkb.XKB_STATE_MATCH_NON_EXCLUSIVE),
-            "StateMatch.XKB_STATE_MATCH_NON_EXCLUSIVE"
-            "|XKB_STATE_MATCH_ALL"
-            "|XKB_STATE_MATCH_ANY")
+        self.assertIn(
+            str(xkb.XKB_STATE_MATCH_ANY | xkb.XKB_STATE_MATCH_ALL),
+            ("StateMatch.XKB_STATE_MATCH_ALL|XKB_STATE_MATCH_ANY",
+             "StateMatch.XKB_STATE_MATCH_ANY|XKB_STATE_MATCH_ALL"))
+
 
 class TestKeyboardState(TestCase):
     capslock = 66
     space = 65
-    
+
     @classmethod
     def setUpClass(cls):
         cls._ctx = xkb.Context()
@@ -267,17 +281,13 @@ class TestKeyboardState(TestCase):
             False)
         keydown = state.update_key(self.capslock, xkb.XKB_KEY_DOWN)
         self.assertEqual(
-            str(keydown),
-            "StateComponent.XKB_STATE_LEDS"
-            "|XKB_STATE_MODS_EFFECTIVE"
-            "|XKB_STATE_MODS_LOCKED"
-            "|XKB_STATE_MODS_DEPRESSED")
+            keydown, xkb.XKB_STATE_LEDS | xkb.XKB_STATE_MODS_EFFECTIVE
+            | xkb.XKB_STATE_MODS_LOCKED | xkb.XKB_STATE_MODS_DEPRESSED)
         self.assertIsInstance(keydown, xkb.StateComponent)
         self.assertIsInstance(keydown, int)
         keyup = state.update_key(self.capslock, xkb.XKB_KEY_UP)
         self.assertEqual(
-            str(keyup),
-            "StateComponent.XKB_STATE_MODS_DEPRESSED")
+            keyup, xkb.XKB_STATE_MODS_DEPRESSED)
         self.assertEqual(
             state.mod_name_is_active("Lock", xkb.XKB_STATE_MODS_LOCKED),
             True)
@@ -305,15 +315,15 @@ class TestKeyboardState(TestCase):
         r = slave_state.update_mask(
             depressed_mods, latched_mods, locked_mods,
             depressed_layout, latched_layout, locked_layout)
+        self.assertIsInstance(r, int)
+        self.assertIsInstance(r, xkb.StateComponent)
         self.assertEqual(
-            str(r),
-            "StateComponent.XKB_STATE_LEDS"
-            "|XKB_STATE_MODS_EFFECTIVE"
-            "|XKB_STATE_MODS_LOCKED")
+            r, xkb.XKB_STATE_LEDS | xkb.XKB_STATE_MODS_EFFECTIVE
+            | xkb.XKB_STATE_MODS_LOCKED)
         self.assertEqual(
             slave_state.mod_name_is_active("Lock", xkb.XKB_STATE_MODS_LOCKED),
             True)
-        
+
     def test_state_key_get_syms(self):
         state = self.km.state_new()
         syms = state.key_get_syms(self.space)
@@ -323,7 +333,7 @@ class TestKeyboardState(TestCase):
         state = self.km.state_new()
         self.assertEqual(state.key_get_string(self.capslock), "")
         self.assertEqual(state.key_get_string(self.space), " ")
-        
+
     def test_state_key_get_one_sym(self):
         state = self.km.state_new()
         self.assertEqual(state.key_get_one_sym(self.capslock), 65509)
@@ -372,7 +382,7 @@ class TestKeyboardState(TestCase):
         state.update_key(self.capslock, xkb.XKB_KEY_UP)
         self.assertTrue(
             state.mod_index_is_active(self.lock, xkb.XKB_STATE_MODS_LOCKED))
-        
+
     def test_state_mod_index_is_active_fail(self):
         state = self.km.state_new()
         with self.assertRaises(xkb.XKBInvalidModifierIndex):
